@@ -8,7 +8,13 @@
 #include <urcu/compiler.h>
 #include <urcu/system.h>
 
+/* #define UATOMIC_HAS_ATOMIC_BYTE */
 #define UATOMIC_HAS_ATOMIC_SHORT
+#define UATOMIC_HAS_ATOMIC_INT
+#if (CAA_BITS_PER_LONG == 64)
+#define UATOMIC_HAS_ATOMIC_LLONG
+#endif
+
 #include <urcu/uatomic/generic.h>
 
 #endif /* _URCU_ARCH_UATOMIC_HPPA_H */
